@@ -36,9 +36,8 @@ using namespace reactphysics3d;
 
 // Constructor
 /**
- * @param transform The transform of the body
- * @param world The physics world where the body is created
- * @param id ID of the body
+ * @param world The reference to the physics world where the body is created
+ * @param entity Entity of the body
  */
 Body::Body(PhysicsWorld& world, Entity entity)
               : mEntity(entity), mWorld(world), mIsDebugEnabled(false)  {
@@ -106,11 +105,15 @@ Collider* Body::addCollider(CollisionShape* collisionShape, const Transform& tra
 
 #endif
 
-    // Compute the world-space AABB of the new collision shape
-    const AABB aabb = collisionShape->computeTransformedAABB(mWorld.mTransformComponents.getTransform(mEntity) * transform);
+    // If the body is active
+    if (isActive) {
 
-    // Notify the collision detection about this new collision shape
-    mWorld.mCollisionDetection.addCollider(collider, aabb);
+        // Compute the world-space AABB of the new collision shape
+        const AABB aabb = collisionShape->computeTransformedAABB(mWorld.mTransformComponents.getTransform(mEntity) * transform);
+
+        // Notify the collision detection about this new collision shape
+        mWorld.mCollisionDetection.addCollider(collider, aabb);
+    }
 
     RP3D_LOG(mWorld.mConfig.worldName, Logger::Level::Information, Logger::Category::Body,
              "Body " + std::to_string(mEntity.id) + ": Collider " + std::to_string(collider->getBroadPhaseId()) + " added to body",  __FILE__, __LINE__);
@@ -133,8 +136,8 @@ uint32 Body::getNbColliders() const {
 
 // Return a const pointer to a given collider of the body
 /**
-* @param index Index of a Collider of the body
-* @return The const pointer of a given collider of the body
+* @param colliderIndex Index of a Collider of the body
+* @return The const pointer to the requested collider
 */
 const Collider* Body::getCollider(uint32 colliderIndex) const {
 
@@ -147,8 +150,8 @@ const Collider* Body::getCollider(uint32 colliderIndex) const {
 
 // Return a pointer to a given collider of the body
 /**
-* @param index Index of a Collider of the body
-* @return The pointer of a given collider of the body
+* @param colliderIndex Index of a Collider of the body
+* @return The pointer to the requested collider
 */
 Collider* Body::getCollider(uint32 colliderIndex) {
 
