@@ -35,9 +35,8 @@ using namespace reactphysics3d;
 
 // Constructor
 /**
-* @param transform The transformation of the body
 * @param world The world where the body has been added
-* @param id The ID of the body
+* @param entity The entity of the rigidbody
 */
 RigidBody::RigidBody(PhysicsWorld& world, Entity entity) : Body(world, entity) {
 
@@ -697,11 +696,16 @@ Collider* RigidBody::addCollider(CollisionShape* collisionShape, const Transform
 
 #endif
 
-    // Compute the world-space AABB of the new collision shape
-    AABB aabb = collisionShape->computeTransformedAABB(mWorld.mTransformComponents.getTransform(mEntity) * transform);
+    // If the body is active
+    const bool isActive = mWorld.mBodyComponents.getIsActive(mEntity);
+    if (isActive) {
 
-    // Notify the collision detection about this new collision shape
-    mWorld.mCollisionDetection.addCollider(collider, aabb);
+        // Compute the world-space AABB of the new collision shape
+        AABB aabb = collisionShape->computeTransformedAABB(mWorld.mTransformComponents.getTransform(mEntity) * transform);
+
+        // Notify the collision detection about this new collision shape
+        mWorld.mCollisionDetection.addCollider(collider, aabb);
+    }
 
     RP3D_LOG(mWorld.mConfig.worldName, Logger::Level::Information, Logger::Category::Body,
              "Body " + std::to_string(mEntity.id) + ": Collider " + std::to_string(collider->getBroadPhaseId()) + " added to body",  __FILE__, __LINE__);
@@ -851,10 +855,10 @@ void RigidBody::setTransform(const Transform& transform) {
         mWorld.mRigidBodyComponents.setConstrainedOrientation(mEntity, transform.getOrientation());
     }
 
-    Body::setTransform(transform);
-
     // Awake the body if it is sleeping
     setIsSleeping(false);
+
+    Body::setTransform(transform);
 }
 
 // Return the linear velocity
